v1.0.6
========
- internal changes to the way library is authenticating user; library uses a public client by default. Now, if provided, the .env file can be used to provide custom client data.
- Research object completeness attribute renamed to completeness_score to avoid conflict 